@@ -1,7 +1,10 @@
+"""Provide the BaseApp class."""
 from ..mixins import BaseModel, DeletableMixin, EditableMixin, OwnerMixin
 
 
 class BaseApp(BaseModel, DeletableMixin, EditableMixin, OwnerMixin):
+    """The base class for all app classes."""
+
     _attrTypes = {**BaseModel._attrTypes, "app_name": "str", "owner_id": "int"}
     _nameAttr = "name"
     _nameMapping = {"app_name": "name"}
