@@ -1,15 +1,14 @@
+"""Provide the RedditApp class."""
 import base64
-import logging
-from typing import Union
+from typing import TYPE_CHECKING, Union
 
-import asyncpraw
 import praw
-from praw.util.token_manager import BaseTokenManager
 
 from ..mixins import BaseApp
-from .utils import resolveModelFromInput, resolveUser
+from .utils import _resolveModelFromInput, _resolveUser
 
-log = logging.getLogger(__package__)
+if TYPE_CHECKING:
+    import asyncpraw
 
 
 class RedditApp(BaseApp):
@@ -73,7 +72,7 @@ class RedditApp(BaseApp):
             self._fetched = True
 
     @staticmethod
-    @resolveUser()
+    @_resolveUser()
     def _create(
         _credmgr,
         name,
@@ -86,7 +85,7 @@ class RedditApp(BaseApp):
         enabled,
         owner=None,
     ):
-        """Create a new Reddit App
+        """Create a new Reddit App.
 
         Reddit Apps are used for interacting with Reddit
 
@@ -129,9 +128,10 @@ class RedditApp(BaseApp):
         *,
         use_async=False,
         use_cache=True,
-        reddit_class: Union[praw.Reddit, asyncpraw.Reddit, None] = None,
+        reddit_class: Union[praw.Reddit, "asyncpraw.Reddit", None] = None,
+        extra_reddit_kwargs=None,
     ) -> praw.Reddit:
-        """Provides an optionally authenticated [Async] PRAW
+        """Provide an optionally authenticated [Async] PRAW instance.
 
         :param str redditor: The redditor that you want the Reddit instance authorized
             as.
@@ -140,34 +140,38 @@ class RedditApp(BaseApp):
             cached already.
         :param reddit_class: The Reddit class to use. Useful if you have a local version
             of PRAW.
+        :param dict extra_reddit_kwargs: Extra kwargs to pass to the Reddit class.
 
         :returns: Reddit instance.
 
         """
+        if extra_reddit_kwargs is None:
+            extra_reddit_kwargs = {}
         if not (isinstance(self._reddit, praw.Reddit) == (not use_async)):
             self._reddit = None
         if not (use_cache and self._reddit):
             if not reddit_class:
                 if use_async:
+                    import asyncpraw
+
                     reddit_class = asyncpraw.Reddit
                 else:
                     reddit_class = praw.Reddit
-            extra_kwargs = {}
             if redditor:
                 refreshToken = self._credmgr.refreshToken(redditor, self.id)
                 if refreshToken:
-                    extra_kwargs['refresh_token'] = refreshToken.refreshToken
+                    extra_reddit_kwargs["refresh_token"] = refreshToken.refreshToken
             self._reddit = reddit_class(
                 client_id=self.clientId,
                 client_secret=self.clientSecret,
                 user_agent=self.userAgent,
                 redirect_uri=self.redirectUri,
-                **extra_kwargs,
+                **extra_reddit_kwargs,
             )
         return self._reddit
 
     def genAuthUrl(self, scopes=None, permanent=False, userVerification=None):
-        """Generates a URL for users to verify or authenticate their Reddit account
+        """Generate a URL for users to verify or authenticate their Reddit account.
 
         :param Union[list,str] scopes: List of scopes needed. Pass ``'all'`` for all
             scopes. The ``identity`` scope will always be included. (default:
@@ -199,7 +203,7 @@ class RedditApp(BaseApp):
             duration = "permanent"
         else:
             duration = "temporary"
-        uVerification = resolveModelFromInput(
+        uVerification = _resolveModelFromInput(
             self._credmgr, UserVerification, userVerification, "userId"
         )
         if not uVerification and userVerification:
