@@ -1,3 +1,4 @@
+"""Provide helper utilities used by other models."""
 import re
 
 from credmgr.exceptions import NotFound
@@ -5,12 +6,11 @@ from credmgr.exceptions import NotFound
 reCamelToSnake = re.compile(r"([a-z0-9](?=[A-Z])|[A-Z](?=[A-Z][a-z]))")
 
 
-def camelToSnake(name: str) -> str:
-    """Convert `name` from camelCase to snake_case."""
+def _camelToSnake(name: str) -> str:
     return reCamelToSnake.sub(r"\1_", name).lower()
 
 
-def resolveUser(userAttr="owner", returnAttr="id"):
+def _resolveUser(userAttr="owner", returnAttr="id"):
     def decorator(func):
         def wrapper(self, *args, **kwargs):
             from . import User
@@ -34,7 +34,7 @@ def resolveUser(userAttr="owner", returnAttr="id"):
     return decorator
 
 
-def resolveModelFromInput(credmgr, model, inputValue, returnAttr="id"):
+def _resolveModelFromInput(credmgr, model, inputValue, returnAttr="id"):
     value = None
     if isinstance(inputValue, model):
         value = getattr(inputValue, returnAttr)
@@ -51,7 +51,22 @@ def resolveModelFromInput(credmgr, model, inputValue, returnAttr="id"):
 
 
 class CachedProperty:
+    """A decorator for caching a property's result.
+
+    Similar to `property`, but the wrapped method's result is cached on the instance.
+    This is achieved by setting an entry in the object's instance dictionary with the
+    same name as the property. When the name is later accessed, the value in the
+    instance dictionary takes precedence over the (non-data descriptor) property.
+
+    This is useful for implementing lazy-loaded properties.
+
+    The cache can be invalidated via `delattr()`, or by modifying `__dict__` directly.
+    It will be repopulated on next access.
+
+    """
+
     def __init__(self, func, doc=None):
+        """Initialize the descriptor."""
         self.func = self.__wrapped__ = func
 
         if doc is None:
@@ -63,6 +78,12 @@ class CachedProperty:
         pass
 
     def __get__(self, item, objtype=None):
+        """Implement descriptor getter.
+
+        Calculate the property's value and then store it in the associated object's
+        instance dictionary.
+
+        """
         if item is None:
             return self
 
